# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'Jeremy Howard and Sylvain Gugger',
                'author_email': 'infos@fast.ai',
                'black_formatting': 'False',
                'branch': 'master',
                'clean_ids': 'False',
                'conda_user': 'fastai',
                'copyright': 'fast.ai',
                'custom_quarto_yml': 'False',
                'custom_sidebar': 'False',
                'description': 'Python supercharged for fastai development',
                'dev_requirements': 'numpy nbdev>=0.2.39 matplotlib pillow torch pandas jupyterlab',
                'doc_baseurl': '/',
                'doc_host': 'https://fastcore.fast.ai',
                'doc_path': '_docs',
                'git_url': 'https://github.com/fastai/fastcore/',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'python',
                'language': 'English',
                'lib_name': 'fastcore',
                'lib_path': 'fastcore',
                'license': 'apache2',
                'min_python': '3.7',
                'nbs_path': 'nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'status': '4',
                'title': 'fastcore',
                'tst_flags': '',
                'user': 'fastai',
                'version': '1.5.21'},
  'syms': { 'fastcore.all': {},
            'fastcore.basics': { 'fastcore.basics.AttrDict': 'https://fastcore.fast.ai/basics.html#attrdict',
                                 'fastcore.basics.AttrDict.copy': 'https://fastcore.fast.ai/basics.html#attrdict.copy',
                                 'fastcore.basics.Float': 'https://fastcore.fast.ai/basics.html#float',
                                 'fastcore.basics.GetAttr': 'https://fastcore.fast.ai/basics.html#getattr',
                                 'fastcore.basics.GetAttrBase': 'https://fastcore.fast.ai/basics.html#getattrbase',
                                 'fastcore.basics.ImportEnum': 'https://fastcore.fast.ai/basics.html#importenum',
                                 'fastcore.basics.ImportEnum.imports': 'https://fastcore.fast.ai/basics.html#importenum.imports',
                                 'fastcore.basics.Inf': 'https://fastcore.fast.ai/basics.html#inf',
                                 'fastcore.basics.Int': 'https://fastcore.fast.ai/basics.html#int',
                                 'fastcore.basics.NullType': 'https://fastcore.fast.ai/basics.html#nulltype',
                                 'fastcore.basics.PrettyString': 'https://fastcore.fast.ai/basics.html#prettystring',
                                 'fastcore.basics.Self': 'https://fastcore.fast.ai/basics.html#self',
                                 'fastcore.basics.ShowPrint': 'https://fastcore.fast.ai/basics.html#showprint',
                                 'fastcore.basics.ShowPrint.show': 'https://fastcore.fast.ai/basics.html#showprint.show',
                                 'fastcore.basics.Stateful': 'https://fastcore.fast.ai/basics.html#stateful',
                                 'fastcore.basics.Str': 'https://fastcore.fast.ai/basics.html#str',
                                 'fastcore.basics.StrEnum': 'https://fastcore.fast.ai/basics.html#strenum',
                                 'fastcore.basics.add': 'https://fastcore.fast.ai/basics.html#add',
                                 'fastcore.basics.add_props': 'https://fastcore.fast.ai/basics.html#add_props',
                                 'fastcore.basics.anno_ret': 'https://fastcore.fast.ai/basics.html#anno_ret',
                                 'fastcore.basics.annotations': 'https://fastcore.fast.ai/basics.html#annotations',
                                 'fastcore.basics.arg0': 'https://fastcore.fast.ai/basics.html#arg0',
                                 'fastcore.basics.arg1': 'https://fastcore.fast.ai/basics.html#arg1',
                                 'fastcore.basics.arg2': 'https://fastcore.fast.ai/basics.html#arg2',
                                 'fastcore.basics.arg3': 'https://fastcore.fast.ai/basics.html#arg3',
                                 'fastcore.basics.arg4': 'https://fastcore.fast.ai/basics.html#arg4',
                                 'fastcore.basics.argnames': 'https://fastcore.fast.ai/basics.html#argnames',
                                 'fastcore.basics.argwhere': 'https://fastcore.fast.ai/basics.html#argwhere',
                                 'fastcore.basics.attrdict': 'https://fastcore.fast.ai/basics.html#attrdict',
                                 'fastcore.basics.basic_repr': 'https://fastcore.fast.ai/basics.html#basic_repr',
                                 'fastcore.basics.bind': 'https://fastcore.fast.ai/basics.html#bind',
                                 'fastcore.basics.camel2snake': 'https://fastcore.fast.ai/basics.html#camel2snake',
                                 'fastcore.basics.camel2words': 'https://fastcore.fast.ai/basics.html#camel2words',
                                 'fastcore.basics.chunked': 'https://fastcore.fast.ai/basics.html#chunked',
                                 'fastcore.basics.class2attr': 'https://fastcore.fast.ai/basics.html#class2attr',
                                 'fastcore.basics.compile_re': 'https://fastcore.fast.ai/basics.html#compile_re',
                                 'fastcore.basics.compose': 'https://fastcore.fast.ai/basics.html#compose',
                                 'fastcore.basics.concat': 'https://fastcore.fast.ai/basics.html#concat',
                                 'fastcore.basics.copy_func': 'https://fastcore.fast.ai/basics.html#copy_func',
                                 'fastcore.basics.custom_dir': 'https://fastcore.fast.ai/basics.html#custom_dir',
                                 'fastcore.basics.cycle': 'https://fastcore.fast.ai/basics.html#cycle',
                                 'fastcore.basics.defaults': 'https://fastcore.fast.ai/basics.html#defaults',
                                 'fastcore.basics.delegate_attr': 'https://fastcore.fast.ai/basics.html#delegate_attr',
                                 'fastcore.basics.detuplify': 'https://fastcore.fast.ai/basics.html#detuplify',
                                 'fastcore.basics.eq': 'https://fastcore.fast.ai/basics.html#eq',
                                 'fastcore.basics.eval_type': 'https://fastcore.fast.ai/basics.html#eval_type',
                                 'fastcore.basics.even_mults': 'https://fastcore.fast.ai/basics.html#even_mults',
                                 'fastcore.basics.exec_import': 'https://fastcore.fast.ai/basics.html#exec_import',
                                 'fastcore.basics.exec_local': 'https://fastcore.fast.ai/basics.html#exec_local',
                                 'fastcore.basics.exec_new': 'https://fastcore.fast.ai/basics.html#exec_new',
                                 'fastcore.basics.fastuple': 'https://fastcore.fast.ai/basics.html#fastuple',
                                 'fastcore.basics.fastuple.add': 'https://fastcore.fast.ai/basics.html#fastuple.add',
                                 'fastcore.basics.fastuple.mul': 'https://fastcore.fast.ai/basics.html#fastuple.mul',
                                 'fastcore.basics.filter_dict': 'https://fastcore.fast.ai/basics.html#filter_dict',
                                 'fastcore.basics.filter_ex': 'https://fastcore.fast.ai/basics.html#filter_ex',
                                 'fastcore.basics.filter_keys': 'https://fastcore.fast.ai/basics.html#filter_keys',
                                 'fastcore.basics.filter_values': 'https://fastcore.fast.ai/basics.html#filter_values',
                                 'fastcore.basics.first': 'https://fastcore.fast.ai/basics.html#first',
                                 'fastcore.basics.flatten': 'https://fastcore.fast.ai/basics.html#flatten',
                                 'fastcore.basics.ge': 'https://fastcore.fast.ai/basics.html#ge',
                                 'fastcore.basics.gen': 'https://fastcore.fast.ai/basics.html#gen',
                                 'fastcore.basics.get_annotations_ex': 'https://fastcore.fast.ai/basics.html#get_annotations_ex',
                                 'fastcore.basics.get_class': 'https://fastcore.fast.ai/basics.html#get_class',
                                 'fastcore.basics.getattrs': 'https://fastcore.fast.ai/basics.html#getattrs',
                                 'fastcore.basics.getcallable': 'https://fastcore.fast.ai/basics.html#getcallable',
                                 'fastcore.basics.groupby': 'https://fastcore.fast.ai/basics.html#groupby',
                                 'fastcore.basics.gt': 'https://fastcore.fast.ai/basics.html#gt',
                                 'fastcore.basics.hasattrs': 'https://fastcore.fast.ai/basics.html#hasattrs',
                                 'fastcore.basics.ifnone': 'https://fastcore.fast.ai/basics.html#ifnone',
                                 'fastcore.basics.ignore_exceptions': 'https://fastcore.fast.ai/basics.html#ignore_exceptions',
                                 'fastcore.basics.in_': 'https://fastcore.fast.ai/basics.html#in_',
                                 'fastcore.basics.instantiate': 'https://fastcore.fast.ai/basics.html#instantiate',
                                 'fastcore.basics.inum_methods': 'https://fastcore.fast.ai/basics.html#inum_methods',
                                 'fastcore.basics.is_': 'https://fastcore.fast.ai/basics.html#is_',
                                 'fastcore.basics.is_array': 'https://fastcore.fast.ai/basics.html#is_array',
                                 'fastcore.basics.is_not': 'https://fastcore.fast.ai/basics.html#is_not',
                                 'fastcore.basics.last_index': 'https://fastcore.fast.ai/basics.html#last_index',
                                 'fastcore.basics.le': 'https://fastcore.fast.ai/basics.html#le',
                                 'fastcore.basics.listify': 'https://fastcore.fast.ai/basics.html#listify',
                                 'fastcore.basics.loop_first': 'https://fastcore.fast.ai/basics.html#loop_first',
                                 'fastcore.basics.loop_first_last': 'https://fastcore.fast.ai/basics.html#loop_first_last',
                                 'fastcore.basics.loop_last': 'https://fastcore.fast.ai/basics.html#loop_last',
                                 'fastcore.basics.lt': 'https://fastcore.fast.ai/basics.html#lt',
                                 'fastcore.basics.map_ex': 'https://fastcore.fast.ai/basics.html#map_ex',
                                 'fastcore.basics.maps': 'https://fastcore.fast.ai/basics.html#maps',
                                 'fastcore.basics.mapt': 'https://fastcore.fast.ai/basics.html#mapt',
                                 'fastcore.basics.maybe_attr': 'https://fastcore.fast.ai/basics.html#maybe_attr',
                                 'fastcore.basics.merge': 'https://fastcore.fast.ai/basics.html#merge',
                                 'fastcore.basics.mk_class': 'https://fastcore.fast.ai/basics.html#mk_class',
                                 'fastcore.basics.mul': 'https://fastcore.fast.ai/basics.html#mul',
                                 'fastcore.basics.ne': 'https://fastcore.fast.ai/basics.html#ne',
                                 'fastcore.basics.nested_attr': 'https://fastcore.fast.ai/basics.html#nested_attr',
                                 'fastcore.basics.nested_callable': 'https://fastcore.fast.ai/basics.html#nested_callable',
                                 'fastcore.basics.nested_idx': 'https://fastcore.fast.ai/basics.html#nested_idx',
                                 'fastcore.basics.nested_setdefault': 'https://fastcore.fast.ai/basics.html#nested_setdefault',
                                 'fastcore.basics.not_': 'https://fastcore.fast.ai/basics.html#not_',
                                 'fastcore.basics.null': 'https://fastcore.fast.ai/basics.html#null',
                                 'fastcore.basics.num_cpus': 'https://fastcore.fast.ai/basics.html#num_cpus',
                                 'fastcore.basics.num_methods': 'https://fastcore.fast.ai/basics.html#num_methods',
                                 'fastcore.basics.only': 'https://fastcore.fast.ai/basics.html#only',
                                 'fastcore.basics.otherwise': 'https://fastcore.fast.ai/basics.html#otherwise',
                                 'fastcore.basics.partialler': 'https://fastcore.fast.ai/basics.html#partialler',
                                 'fastcore.basics.patch': 'https://fastcore.fast.ai/basics.html#patch',
                                 'fastcore.basics.patch_property': 'https://fastcore.fast.ai/basics.html#patch_property',
                                 'fastcore.basics.patch_to': 'https://fastcore.fast.ai/basics.html#patch_to',
                                 'fastcore.basics.properties': 'https://fastcore.fast.ai/basics.html#properties',
                                 'fastcore.basics.range_of': 'https://fastcore.fast.ai/basics.html#range_of',
                                 'fastcore.basics.renumerate': 'https://fastcore.fast.ai/basics.html#renumerate',
                                 'fastcore.basics.replicate': 'https://fastcore.fast.ai/basics.html#replicate',
                                 'fastcore.basics.risinstance': 'https://fastcore.fast.ai/basics.html#risinstance',
                                 'fastcore.basics.rnum_methods': 'https://fastcore.fast.ai/basics.html#rnum_methods',
                                 'fastcore.basics.set_nested_idx': 'https://fastcore.fast.ai/basics.html#set_nested_idx',
                                 'fastcore.basics.setattrs': 'https://fastcore.fast.ai/basics.html#setattrs',
                                 'fastcore.basics.setify': 'https://fastcore.fast.ai/basics.html#setify',
                                 'fastcore.basics.signature_ex': 'https://fastcore.fast.ai/basics.html#signature_ex',
                                 'fastcore.basics.snake2camel': 'https://fastcore.fast.ai/basics.html#snake2camel',
                                 'fastcore.basics.sorted_ex': 'https://fastcore.fast.ai/basics.html#sorted_ex',
                                 'fastcore.basics.stop': 'https://fastcore.fast.ai/basics.html#stop',
                                 'fastcore.basics.store_attr': 'https://fastcore.fast.ai/basics.html#store_attr',
                                 'fastcore.basics.str2bool': 'https://fastcore.fast.ai/basics.html#str2bool',
                                 'fastcore.basics.str_enum': 'https://fastcore.fast.ai/basics.html#str_enum',
                                 'fastcore.basics.strcat': 'https://fastcore.fast.ai/basics.html#strcat',
                                 'fastcore.basics.sub': 'https://fastcore.fast.ai/basics.html#sub',
                                 'fastcore.basics.tonull': 'https://fastcore.fast.ai/basics.html#tonull',
                                 'fastcore.basics.true': 'https://fastcore.fast.ai/basics.html#true',
                                 'fastcore.basics.truediv': 'https://fastcore.fast.ai/basics.html#truediv',
                                 'fastcore.basics.try_attrs': 'https://fastcore.fast.ai/basics.html#try_attrs',
                                 'fastcore.basics.tuplify': 'https://fastcore.fast.ai/basics.html#tuplify',
                                 'fastcore.basics.type_hints': 'https://fastcore.fast.ai/basics.html#type_hints',
                                 'fastcore.basics.typed': 'https://fastcore.fast.ai/basics.html#typed',
                                 'fastcore.basics.union2tuple': 'https://fastcore.fast.ai/basics.html#union2tuple',
                                 'fastcore.basics.uniqueify': 'https://fastcore.fast.ai/basics.html#uniqueify',
                                 'fastcore.basics.using_attr': 'https://fastcore.fast.ai/basics.html#using_attr',
                                 'fastcore.basics.val2idx': 'https://fastcore.fast.ai/basics.html#val2idx',
                                 'fastcore.basics.with_cast': 'https://fastcore.fast.ai/basics.html#with_cast',
                                 'fastcore.basics.wrap_class': 'https://fastcore.fast.ai/basics.html#wrap_class',
                                 'fastcore.basics.zip_cycle': 'https://fastcore.fast.ai/basics.html#zip_cycle'},
            'fastcore.dispatch': { 'fastcore.dispatch.DispatchReg': 'https://fastcore.fast.ai/dispatch.html#dispatchreg',
                                   'fastcore.dispatch.TypeDispatch': 'https://fastcore.fast.ai/dispatch.html#typedispatch',
                                   'fastcore.dispatch.TypeDispatch.add': 'https://fastcore.fast.ai/dispatch.html#typedispatch.add',
                                   'fastcore.dispatch.TypeDispatch.first': 'https://fastcore.fast.ai/dispatch.html#typedispatch.first',
                                   'fastcore.dispatch.TypeDispatch.returns': 'https://fastcore.fast.ai/dispatch.html#typedispatch.returns',
                                   'fastcore.dispatch.cast': 'https://fastcore.fast.ai/dispatch.html#cast',
                                   'fastcore.dispatch.default_set_meta': 'https://fastcore.fast.ai/dispatch.html#default_set_meta',
                                   'fastcore.dispatch.explode_types': 'https://fastcore.fast.ai/dispatch.html#explode_types',
                                   'fastcore.dispatch.lenient_issubclass': 'https://fastcore.fast.ai/dispatch.html#lenient_issubclass',
                                   'fastcore.dispatch.retain_meta': 'https://fastcore.fast.ai/dispatch.html#retain_meta',
                                   'fastcore.dispatch.retain_type': 'https://fastcore.fast.ai/dispatch.html#retain_type',
                                   'fastcore.dispatch.retain_types': 'https://fastcore.fast.ai/dispatch.html#retain_types',
                                   'fastcore.dispatch.sorted_topologically': 'https://fastcore.fast.ai/dispatch.html#sorted_topologically',
                                   'fastcore.dispatch.typedispatch': 'https://fastcore.fast.ai/dispatch.html#typedispatch'},
            'fastcore.docments': { 'fastcore.docments.docments': 'https://fastcore.fast.ai/docments.html#docments',
                                   'fastcore.docments.docstring': 'https://fastcore.fast.ai/docments.html#docstring',
                                   'fastcore.docments.empty': 'https://fastcore.fast.ai/docments.html#empty',
                                   'fastcore.docments.get_dataclass_source': 'https://fastcore.fast.ai/docments.html#get_dataclass_source',
                                   'fastcore.docments.get_name': 'https://fastcore.fast.ai/docments.html#get_name',
                                   'fastcore.docments.get_source': 'https://fastcore.fast.ai/docments.html#get_source',
                                   'fastcore.docments.isdataclass': 'https://fastcore.fast.ai/docments.html#isdataclass',
                                   'fastcore.docments.parse_docstring': 'https://fastcore.fast.ai/docments.html#parse_docstring',
                                   'fastcore.docments.qual_name': 'https://fastcore.fast.ai/docments.html#qual_name'},
            'fastcore.docscrape': { 'fastcore.docscrape.NumpyDocString': 'https://fastcore.fast.ai/docscrape.html#numpydocstring',
                                    'fastcore.docscrape.Parameter': 'https://fastcore.fast.ai/docscrape.html#parameter',
                                    'fastcore.docscrape.dedent_lines': 'https://fastcore.fast.ai/docscrape.html#dedent_lines'},
            'fastcore.foundation': { 'fastcore.foundation.CollBase': 'https://fastcore.fast.ai/foundation.html#collbase',
                                     'fastcore.foundation.Config': 'https://fastcore.fast.ai/foundation.html#config',
                                     'fastcore.foundation.Config.get': 'https://fastcore.fast.ai/foundation.html#config.get',
                                     'fastcore.foundation.Config.path': 'https://fastcore.fast.ai/foundation.html#config.path',
                                     'fastcore.foundation.Config.save': 'https://fastcore.fast.ai/foundation.html#config.save',
                                     'fastcore.foundation.L': 'https://fastcore.fast.ai/foundation.html#l',
                                     'fastcore.foundation.L.argfirst': 'https://fastcore.fast.ai/foundation.html#l.argfirst',
                                     'fastcore.foundation.L.argwhere': 'https://fastcore.fast.ai/foundation.html#l.argwhere',
                                     'fastcore.foundation.L.attrgot': 'https://fastcore.fast.ai/foundation.html#l.attrgot',
                                     'fastcore.foundation.L.concat': 'https://fastcore.fast.ai/foundation.html#l.concat',
                                     'fastcore.foundation.L.copy': 'https://fastcore.fast.ai/foundation.html#l.copy',
                                     'fastcore.foundation.L.cycle': 'https://fastcore.fast.ai/foundation.html#l.cycle',
                                     'fastcore.foundation.L.enumerate': 'https://fastcore.fast.ai/foundation.html#l.enumerate',
                                     'fastcore.foundation.L.filter': 'https://fastcore.fast.ai/foundation.html#l.filter',
                                     'fastcore.foundation.L.itemgot': 'https://fastcore.fast.ai/foundation.html#l.itemgot',
                                     'fastcore.foundation.L.map': 'https://fastcore.fast.ai/foundation.html#l.map',
                                     'fastcore.foundation.L.map_dict': 'https://fastcore.fast.ai/foundation.html#l.map_dict',
                                     'fastcore.foundation.L.map_first': 'https://fastcore.fast.ai/foundation.html#l.map_first',
                                     'fastcore.foundation.L.map_zip': 'https://fastcore.fast.ai/foundation.html#l.map_zip',
                                     'fastcore.foundation.L.map_zipwith': 'https://fastcore.fast.ai/foundation.html#l.map_zipwith',
                                     'fastcore.foundation.L.product': 'https://fastcore.fast.ai/foundation.html#l.product',
                                     'fastcore.foundation.L.range': 'https://fastcore.fast.ai/foundation.html#l.range',
                                     'fastcore.foundation.L.reduce': 'https://fastcore.fast.ai/foundation.html#l.reduce',
                                     'fastcore.foundation.L.renumerate': 'https://fastcore.fast.ai/foundation.html#l.renumerate',
                                     'fastcore.foundation.L.setattrs': 'https://fastcore.fast.ai/foundation.html#l.setattrs',
                                     'fastcore.foundation.L.shuffle': 'https://fastcore.fast.ai/foundation.html#l.shuffle',
                                     'fastcore.foundation.L.sorted': 'https://fastcore.fast.ai/foundation.html#l.sorted',
                                     'fastcore.foundation.L.split': 'https://fastcore.fast.ai/foundation.html#l.split',
                                     'fastcore.foundation.L.starmap': 'https://fastcore.fast.ai/foundation.html#l.starmap',
                                     'fastcore.foundation.L.sum': 'https://fastcore.fast.ai/foundation.html#l.sum',
                                     'fastcore.foundation.L.unique': 'https://fastcore.fast.ai/foundation.html#l.unique',
                                     'fastcore.foundation.L.val2idx': 'https://fastcore.fast.ai/foundation.html#l.val2idx',
                                     'fastcore.foundation.L.zip': 'https://fastcore.fast.ai/foundation.html#l.zip',
                                     'fastcore.foundation.L.zipwith': 'https://fastcore.fast.ai/foundation.html#l.zipwith',
                                     'fastcore.foundation.add_docs': 'https://fastcore.fast.ai/foundation.html#add_docs',
                                     'fastcore.foundation.coll_repr': 'https://fastcore.fast.ai/foundation.html#coll_repr',
                                     'fastcore.foundation.cycle': 'https://fastcore.fast.ai/foundation.html#cycle',
                                     'fastcore.foundation.docs': 'https://fastcore.fast.ai/foundation.html#docs',
                                     'fastcore.foundation.is_bool': 'https://fastcore.fast.ai/foundation.html#is_bool',
                                     'fastcore.foundation.is_indexer': 'https://fastcore.fast.ai/foundation.html#is_indexer',
                                     'fastcore.foundation.mask2idxs': 'https://fastcore.fast.ai/foundation.html#mask2idxs',
                                     'fastcore.foundation.read_config_file': 'https://fastcore.fast.ai/foundation.html#read_config_file',
                                     'fastcore.foundation.save_config_file': 'https://fastcore.fast.ai/foundation.html#save_config_file',
                                     'fastcore.foundation.working_directory': 'https://fastcore.fast.ai/foundation.html#working_directory',
                                     'fastcore.foundation.zip_cycle': 'https://fastcore.fast.ai/foundation.html#zip_cycle'},
            'fastcore.imports': { 'fastcore.imports.IN_COLAB': 'https://fastcore.fast.ai/imports.html#in_colab',
                                  'fastcore.imports.IN_IPYTHON': 'https://fastcore.fast.ai/imports.html#in_ipython',
                                  'fastcore.imports.IN_JUPYTER': 'https://fastcore.fast.ai/imports.html#in_jupyter',
                                  'fastcore.imports.IN_NOTEBOOK': 'https://fastcore.fast.ai/imports.html#in_notebook',
                                  'fastcore.imports.NoneType': 'https://fastcore.fast.ai/imports.html#nonetype',
                                  'fastcore.imports.all_equal': 'https://fastcore.fast.ai/imports.html#all_equal',
                                  'fastcore.imports.any_is_instance': 'https://fastcore.fast.ai/imports.html#any_is_instance',
                                  'fastcore.imports.array_equal': 'https://fastcore.fast.ai/imports.html#array_equal',
                                  'fastcore.imports.df_equal': 'https://fastcore.fast.ai/imports.html#df_equal',
                                  'fastcore.imports.equals': 'https://fastcore.fast.ai/imports.html#equals',
                                  'fastcore.imports.in_colab': 'https://fastcore.fast.ai/imports.html#in_colab',
                                  'fastcore.imports.in_ipython': 'https://fastcore.fast.ai/imports.html#in_ipython',
                                  'fastcore.imports.in_jupyter': 'https://fastcore.fast.ai/imports.html#in_jupyter',
                                  'fastcore.imports.in_notebook': 'https://fastcore.fast.ai/imports.html#in_notebook',
                                  'fastcore.imports.ipython_shell': 'https://fastcore.fast.ai/imports.html#ipython_shell',
                                  'fastcore.imports.is_coll': 'https://fastcore.fast.ai/imports.html#is_coll',
                                  'fastcore.imports.is_iter': 'https://fastcore.fast.ai/imports.html#is_iter',
                                  'fastcore.imports.isinstance_str': 'https://fastcore.fast.ai/imports.html#isinstance_str',
                                  'fastcore.imports.noop': 'https://fastcore.fast.ai/imports.html#noop',
                                  'fastcore.imports.noops': 'https://fastcore.fast.ai/imports.html#noops',
                                  'fastcore.imports.remove_prefix': 'https://fastcore.fast.ai/imports.html#remove_prefix',
                                  'fastcore.imports.remove_suffix': 'https://fastcore.fast.ai/imports.html#remove_suffix',
                                  'fastcore.imports.string_classes': 'https://fastcore.fast.ai/imports.html#string_classes'},
            'fastcore.meta': { 'fastcore.meta.AutoInit': 'https://fastcore.fast.ai/meta.html#autoinit',
                               'fastcore.meta.BypassNewMeta': 'https://fastcore.fast.ai/meta.html#bypassnewmeta',
                               'fastcore.meta.FixSigMeta': 'https://fastcore.fast.ai/meta.html#fixsigmeta',
                               'fastcore.meta.NewChkMeta': 'https://fastcore.fast.ai/meta.html#newchkmeta',
                               'fastcore.meta.PrePostInitMeta': 'https://fastcore.fast.ai/meta.html#prepostinitmeta',
                               'fastcore.meta.anno_dict': 'https://fastcore.fast.ai/meta.html#anno_dict',
                               'fastcore.meta.delegates': 'https://fastcore.fast.ai/meta.html#delegates',
                               'fastcore.meta.empty2none': 'https://fastcore.fast.ai/meta.html#empty2none',
                               'fastcore.meta.funcs_kwargs': 'https://fastcore.fast.ai/meta.html#funcs_kwargs',
                               'fastcore.meta.method': 'https://fastcore.fast.ai/meta.html#method',
                               'fastcore.meta.test_sig': 'https://fastcore.fast.ai/meta.html#test_sig',
                               'fastcore.meta.use_kwargs': 'https://fastcore.fast.ai/meta.html#use_kwargs',
                               'fastcore.meta.use_kwargs_dict': 'https://fastcore.fast.ai/meta.html#use_kwargs_dict'},
            'fastcore.nb_imports': {},
            'fastcore.net': { 'fastcore.net.ExceptionsHTTP': 'https://fastcore.fast.ai/net.html#exceptionshttp',
                              'fastcore.net.HTTP400BadRequestError': 'https://fastcore.fast.ai/net.html#http400badrequesterror',
                              'fastcore.net.HTTP401UnauthorizedError': 'https://fastcore.fast.ai/net.html#http401unauthorizederror',
                              'fastcore.net.HTTP402PaymentRequiredError': 'https://fastcore.fast.ai/net.html#http402paymentrequirederror',
                              'fastcore.net.HTTP403ForbiddenError': 'https://fastcore.fast.ai/net.html#http403forbiddenerror',
                              'fastcore.net.HTTP404NotFoundError': 'https://fastcore.fast.ai/net.html#http404notfounderror',
                              'fastcore.net.HTTP405MethodNotAllowedError': 'https://fastcore.fast.ai/net.html#http405methodnotallowederror',
                              'fastcore.net.HTTP406NotAcceptableError': 'https://fastcore.fast.ai/net.html#http406notacceptableerror',
                              'fastcore.net.HTTP407ProxyAuthRequiredError': 'https://fastcore.fast.ai/net.html#http407proxyauthrequirederror',
                              'fastcore.net.HTTP408RequestTimeoutError': 'https://fastcore.fast.ai/net.html#http408requesttimeouterror',
                              'fastcore.net.HTTP409ConflictError': 'https://fastcore.fast.ai/net.html#http409conflicterror',
                              'fastcore.net.HTTP410GoneError': 'https://fastcore.fast.ai/net.html#http410goneerror',
                              'fastcore.net.HTTP411LengthRequiredError': 'https://fastcore.fast.ai/net.html#http411lengthrequirederror',
                              'fastcore.net.HTTP412PreconditionFailedError': 'https://fastcore.fast.ai/net.html#http412preconditionfailederror',
                              'fastcore.net.HTTP413PayloadTooLargeError': 'https://fastcore.fast.ai/net.html#http413payloadtoolargeerror',
                              'fastcore.net.HTTP414URITooLongError': 'https://fastcore.fast.ai/net.html#http414uritoolongerror',
                              'fastcore.net.HTTP415UnsupportedMediaTypeError': 'https://fastcore.fast.ai/net.html#http415unsupportedmediatypeerror',
                              'fastcore.net.HTTP416RangeNotSatisfiableError': 'https://fastcore.fast.ai/net.html#http416rangenotsatisfiableerror',
                              'fastcore.net.HTTP417ExpectationFailedError': 'https://fastcore.fast.ai/net.html#http417expectationfailederror',
                              'fastcore.net.HTTP418AmAteapotError': 'https://fastcore.fast.ai/net.html#http418amateapoterror',
                              'fastcore.net.HTTP421MisdirectedRequestError': 'https://fastcore.fast.ai/net.html#http421misdirectedrequesterror',
                              'fastcore.net.HTTP422UnprocessableEntityError': 'https://fastcore.fast.ai/net.html#http422unprocessableentityerror',
                              'fastcore.net.HTTP423LockedError': 'https://fastcore.fast.ai/net.html#http423lockederror',
                              'fastcore.net.HTTP424FailedDependencyError': 'https://fastcore.fast.ai/net.html#http424faileddependencyerror',
                              'fastcore.net.HTTP425TooEarlyError': 'https://fastcore.fast.ai/net.html#http425tooearlyerror',
                              'fastcore.net.HTTP426UpgradeRequiredError': 'https://fastcore.fast.ai/net.html#http426upgraderequirederror',
                              'fastcore.net.HTTP428PreconditionRequiredError': 'https://fastcore.fast.ai/net.html#http428preconditionrequirederror',
                              'fastcore.net.HTTP429TooManyRequestsError': 'https://fastcore.fast.ai/net.html#http429toomanyrequestserror',
                              'fastcore.net.HTTP431HeaderFieldsTooLargeError': 'https://fastcore.fast.ai/net.html#http431headerfieldstoolargeerror',
                              'fastcore.net.HTTP451LegalReasonsError': 'https://fastcore.fast.ai/net.html#http451legalreasonserror',
                              'fastcore.net.HTTP4xxClientError': 'https://fastcore.fast.ai/net.html#http4xxclienterror',
                              'fastcore.net.HTTP5xxServerError': 'https://fastcore.fast.ai/net.html#http5xxservererror',
                              'fastcore.net.Request.summary': 'https://fastcore.fast.ai/net.html#request.summary',
                              'fastcore.net.do_request': 'https://fastcore.fast.ai/net.html#do_request',
                              'fastcore.net.start_client': 'https://fastcore.fast.ai/net.html#start_client',
                              'fastcore.net.start_server': 'https://fastcore.fast.ai/net.html#start_server',
                              'fastcore.net.url_default_headers': 'https://fastcore.fast.ai/net.html#url_default_headers',
                              'fastcore.net.urlcheck': 'https://fastcore.fast.ai/net.html#urlcheck',
                              'fastcore.net.urlclean': 'https://fastcore.fast.ai/net.html#urlclean',
                              'fastcore.net.urldest': 'https://fastcore.fast.ai/net.html#urldest',
                              'fastcore.net.urljson': 'https://fastcore.fast.ai/net.html#urljson',
                              'fastcore.net.urlopen': 'https://fastcore.fast.ai/net.html#urlopen',
                              'fastcore.net.urlopener': 'https://fastcore.fast.ai/net.html#urlopener',
                              'fastcore.net.urlquote': 'https://fastcore.fast.ai/net.html#urlquote',
                              'fastcore.net.urlread': 'https://fastcore.fast.ai/net.html#urlread',
                              'fastcore.net.urlrequest': 'https://fastcore.fast.ai/net.html#urlrequest',
                              'fastcore.net.urlretrieve': 'https://fastcore.fast.ai/net.html#urlretrieve',
                              'fastcore.net.urlsave': 'https://fastcore.fast.ai/net.html#urlsave',
                              'fastcore.net.urlsend': 'https://fastcore.fast.ai/net.html#urlsend',
                              'fastcore.net.urlvalid': 'https://fastcore.fast.ai/net.html#urlvalid',
                              'fastcore.net.urlwrap': 'https://fastcore.fast.ai/net.html#urlwrap'},
            'fastcore.parallel': { 'fastcore.parallel.ProcessPoolExecutor': 'https://fastcore.fast.ai/parallel.html#processpoolexecutor',
                                   'fastcore.parallel.ProcessPoolExecutor.map': 'https://fastcore.fast.ai/parallel.html#processpoolexecutor.map',
                                   'fastcore.parallel.ThreadPoolExecutor': 'https://fastcore.fast.ai/parallel.html#threadpoolexecutor',
                                   'fastcore.parallel.ThreadPoolExecutor.map': 'https://fastcore.fast.ai/parallel.html#threadpoolexecutor.map',
                                   'fastcore.parallel.add_one': 'https://fastcore.fast.ai/parallel.html#add_one',
                                   'fastcore.parallel.parallel': 'https://fastcore.fast.ai/parallel.html#parallel',
                                   'fastcore.parallel.parallel_gen': 'https://fastcore.fast.ai/parallel.html#parallel_gen',
                                   'fastcore.parallel.parallelable': 'https://fastcore.fast.ai/parallel.html#parallelable',
                                   'fastcore.parallel.run_procs': 'https://fastcore.fast.ai/parallel.html#run_procs',
                                   'fastcore.parallel.startthread': 'https://fastcore.fast.ai/parallel.html#startthread',
                                   'fastcore.parallel.threaded': 'https://fastcore.fast.ai/parallel.html#threaded'},
            'fastcore.script': { 'fastcore.script.Param': 'https://fastcore.fast.ai/script.html#param',
                                 'fastcore.script.Param.kwargs': 'https://fastcore.fast.ai/script.html#param.kwargs',
                                 'fastcore.script.Param.pre': 'https://fastcore.fast.ai/script.html#param.pre',
                                 'fastcore.script.Param.set_default': 'https://fastcore.fast.ai/script.html#param.set_default',
                                 'fastcore.script.SCRIPT_INFO': 'https://fastcore.fast.ai/script.html#script_info',
                                 'fastcore.script.anno_parser': 'https://fastcore.fast.ai/script.html#anno_parser',
                                 'fastcore.script.args_from_prog': 'https://fastcore.fast.ai/script.html#args_from_prog',
                                 'fastcore.script.bool_arg': 'https://fastcore.fast.ai/script.html#bool_arg',
                                 'fastcore.script.call_parse': 'https://fastcore.fast.ai/script.html#call_parse',
                                 'fastcore.script.clean_type_str': 'https://fastcore.fast.ai/script.html#clean_type_str',
                                 'fastcore.script.store_false': 'https://fastcore.fast.ai/script.html#store_false',
                                 'fastcore.script.store_true': 'https://fastcore.fast.ai/script.html#store_true'},
            'fastcore.shutil': { 'fastcore.shutil.chown': 'https://fastcore.fast.ai/shutil.html#chown',
                                 'fastcore.shutil.copy': 'https://fastcore.fast.ai/shutil.html#copy',
                                 'fastcore.shutil.copy2': 'https://fastcore.fast.ai/shutil.html#copy2',
                                 'fastcore.shutil.copymode': 'https://fastcore.fast.ai/shutil.html#copymode',
                                 'fastcore.shutil.copystat': 'https://fastcore.fast.ai/shutil.html#copystat',
                                 'fastcore.shutil.copytree': 'https://fastcore.fast.ai/shutil.html#copytree',
                                 'fastcore.shutil.disk_usage': 'https://fastcore.fast.ai/shutil.html#disk_usage',
                                 'fastcore.shutil.move': 'https://fastcore.fast.ai/shutil.html#move',
                                 'fastcore.shutil.rmtree': 'https://fastcore.fast.ai/shutil.html#rmtree'},
            'fastcore.style': { 'fastcore.style.S': 'https://fastcore.fast.ai/style.html#s',
                                'fastcore.style.Style': 'https://fastcore.fast.ai/style.html#style',
                                'fastcore.style.StyleCode': 'https://fastcore.fast.ai/style.html#stylecode',
                                'fastcore.style.demo': 'https://fastcore.fast.ai/style.html#demo',
                                'fastcore.style.style_codes': 'https://fastcore.fast.ai/style.html#style_codes'},
            'fastcore.test': { 'fastcore.test.ExceptionExpected': 'https://fastcore.fast.ai/test.html#exceptionexpected',
                               'fastcore.test.TEST_IMAGE': 'https://fastcore.fast.ai/test.html#test_image',
                               'fastcore.test.TEST_IMAGE_BW': 'https://fastcore.fast.ai/test.html#test_image_bw',
                               'fastcore.test.exception': 'https://fastcore.fast.ai/test.html#exception',
                               'fastcore.test.is_close': 'https://fastcore.fast.ai/test.html#is_close',
                               'fastcore.test.nequals': 'https://fastcore.fast.ai/test.html#nequals',
                               'fastcore.test.test': 'https://fastcore.fast.ai/test.html#test',
                               'fastcore.test.test_close': 'https://fastcore.fast.ai/test.html#test_close',
                               'fastcore.test.test_eq': 'https://fastcore.fast.ai/test.html#test_eq',
                               'fastcore.test.test_eq_type': 'https://fastcore.fast.ai/test.html#test_eq_type',
                               'fastcore.test.test_fail': 'https://fastcore.fast.ai/test.html#test_fail',
                               'fastcore.test.test_fig_exists': 'https://fastcore.fast.ai/test.html#test_fig_exists',
                               'fastcore.test.test_is': 'https://fastcore.fast.ai/test.html#test_is',
                               'fastcore.test.test_ne': 'https://fastcore.fast.ai/test.html#test_ne',
                               'fastcore.test.test_shuffled': 'https://fastcore.fast.ai/test.html#test_shuffled',
                               'fastcore.test.test_stdout': 'https://fastcore.fast.ai/test.html#test_stdout',
                               'fastcore.test.test_warns': 'https://fastcore.fast.ai/test.html#test_warns'},
            'fastcore.transform': { 'fastcore.transform.DisplayedTransform': 'https://fastcore.fast.ai/transform.html#displayedtransform',
                                    'fastcore.transform.DisplayedTransform.name': 'https://fastcore.fast.ai/transform.html#displayedtransform.name',
                                    'fastcore.transform.Func': 'https://fastcore.fast.ai/transform.html#func',
                                    'fastcore.transform.InplaceTransform': 'https://fastcore.fast.ai/transform.html#inplacetransform',
                                    'fastcore.transform.ItemTransform': 'https://fastcore.fast.ai/transform.html#itemtransform',
                                    'fastcore.transform.ItemTransform.decode': 'https://fastcore.fast.ai/transform.html#itemtransform.decode',
                                    'fastcore.transform.Pipeline': 'https://fastcore.fast.ai/transform.html#pipeline',
                                    'fastcore.transform.Pipeline.add': 'https://fastcore.fast.ai/transform.html#pipeline.add',
                                    'fastcore.transform.Pipeline.decode': 'https://fastcore.fast.ai/transform.html#pipeline.decode',
                                    'fastcore.transform.Pipeline.setup': 'https://fastcore.fast.ai/transform.html#pipeline.setup',
                                    'fastcore.transform.Pipeline.show': 'https://fastcore.fast.ai/transform.html#pipeline.show',
                                    'fastcore.transform.Sig': 'https://fastcore.fast.ai/transform.html#sig',
                                    'fastcore.transform.Transform': 'https://fastcore.fast.ai/transform.html#transform',
                                    'fastcore.transform.Transform.decode': 'https://fastcore.fast.ai/transform.html#transform.decode',
                                    'fastcore.transform.Transform.name': 'https://fastcore.fast.ai/transform.html#transform.name',
                                    'fastcore.transform.Transform.setup': 'https://fastcore.fast.ai/transform.html#transform.setup',
                                    'fastcore.transform.compose_tfms': 'https://fastcore.fast.ai/transform.html#compose_tfms',
                                    'fastcore.transform.gather_attr_names': 'https://fastcore.fast.ai/transform.html#gather_attr_names',
                                    'fastcore.transform.gather_attrs': 'https://fastcore.fast.ai/transform.html#gather_attrs',
                                    'fastcore.transform.get_func': 'https://fastcore.fast.ai/transform.html#get_func',
                                    'fastcore.transform.mk_transform': 'https://fastcore.fast.ai/transform.html#mk_transform'},
            'fastcore.utils': {},
            'fastcore.xdg': { 'fastcore.xdg.xdg_cache_home': 'https://fastcore.fast.ai/xdg.html#xdg_cache_home',
                              'fastcore.xdg.xdg_config_dirs': 'https://fastcore.fast.ai/xdg.html#xdg_config_dirs',
                              'fastcore.xdg.xdg_config_home': 'https://fastcore.fast.ai/xdg.html#xdg_config_home',
                              'fastcore.xdg.xdg_data_dirs': 'https://fastcore.fast.ai/xdg.html#xdg_data_dirs',
                              'fastcore.xdg.xdg_data_home': 'https://fastcore.fast.ai/xdg.html#xdg_data_home',
                              'fastcore.xdg.xdg_runtime_dir': 'https://fastcore.fast.ai/xdg.html#xdg_runtime_dir',
                              'fastcore.xdg.xdg_state_home': 'https://fastcore.fast.ai/xdg.html#xdg_state_home'},
            'fastcore.xtras': { 'fastcore.xtras.ContextManagers': 'https://fastcore.fast.ai/xtras.html#contextmanagers',
                                'fastcore.xtras.EventTimer': 'https://fastcore.fast.ai/xtras.html#eventtimer',
                                'fastcore.xtras.EventTimer.add': 'https://fastcore.fast.ai/xtras.html#eventtimer.add',
                                'fastcore.xtras.EventTimer.duration': 'https://fastcore.fast.ai/xtras.html#eventtimer.duration',
                                'fastcore.xtras.EventTimer.freq': 'https://fastcore.fast.ai/xtras.html#eventtimer.freq',
                                'fastcore.xtras.IterLen': 'https://fastcore.fast.ai/xtras.html#iterlen',
                                'fastcore.xtras.PartialFormatter': 'https://fastcore.fast.ai/xtras.html#partialformatter',
                                'fastcore.xtras.PartialFormatter.check_unused_args': 'https://fastcore.fast.ai/xtras.html#partialformatter.check_unused_args',
                                'fastcore.xtras.PartialFormatter.get_field': 'https://fastcore.fast.ai/xtras.html#partialformatter.get_field',
                                'fastcore.xtras.Path.__repr__': 'https://fastcore.fast.ai/xtras.html#path.__repr__',
                                'fastcore.xtras.Path.delete': 'https://fastcore.fast.ai/xtras.html#path.delete',
                                'fastcore.xtras.Path.ls': 'https://fastcore.fast.ai/xtras.html#path.ls',
                                'fastcore.xtras.Path.mk_write': 'https://fastcore.fast.ai/xtras.html#path.mk_write',
                                'fastcore.xtras.Path.read_json': 'https://fastcore.fast.ai/xtras.html#path.read_json',
                                'fastcore.xtras.Path.readlines': 'https://fastcore.fast.ai/xtras.html#path.readlines',
                                'fastcore.xtras.Path.relpath': 'https://fastcore.fast.ai/xtras.html#path.relpath',
                                'fastcore.xtras.ReindexCollection': 'https://fastcore.fast.ai/xtras.html#reindexcollection',
                                'fastcore.xtras.ReindexCollection.cache_clear': 'https://fastcore.fast.ai/xtras.html#reindexcollection.cache_clear',
                                'fastcore.xtras.ReindexCollection.reindex': 'https://fastcore.fast.ai/xtras.html#reindexcollection.reindex',
                                'fastcore.xtras.ReindexCollection.shuffle': 'https://fastcore.fast.ai/xtras.html#reindexcollection.shuffle',
                                'fastcore.xtras.autostart': 'https://fastcore.fast.ai/xtras.html#autostart',
                                'fastcore.xtras.bunzip': 'https://fastcore.fast.ai/xtras.html#bunzip',
                                'fastcore.xtras.console_help': 'https://fastcore.fast.ai/xtras.html#console_help',
                                'fastcore.xtras.dict2obj': 'https://fastcore.fast.ai/xtras.html#dict2obj',
                                'fastcore.xtras.dumps': 'https://fastcore.fast.ai/xtras.html#dumps',
                                'fastcore.xtras.get_source_link': 'https://fastcore.fast.ai/xtras.html#get_source_link',
                                'fastcore.xtras.globtastic': 'https://fastcore.fast.ai/xtras.html#globtastic',
                                'fastcore.xtras.image_size': 'https://fastcore.fast.ai/xtras.html#image_size',
                                'fastcore.xtras.is_listy': 'https://fastcore.fast.ai/xtras.html#is_listy',
                                'fastcore.xtras.join_path_file': 'https://fastcore.fast.ai/xtras.html#join_path_file',
                                'fastcore.xtras.load_pickle': 'https://fastcore.fast.ai/xtras.html#load_pickle',
                                'fastcore.xtras.loads': 'https://fastcore.fast.ai/xtras.html#loads',
                                'fastcore.xtras.loads_multi': 'https://fastcore.fast.ai/xtras.html#loads_multi',
                                'fastcore.xtras.local2utc': 'https://fastcore.fast.ai/xtras.html#local2utc',
                                'fastcore.xtras.mapped': 'https://fastcore.fast.ai/xtras.html#mapped',
                                'fastcore.xtras.maybe_open': 'https://fastcore.fast.ai/xtras.html#maybe_open',
                                'fastcore.xtras.modified_env': 'https://fastcore.fast.ai/xtras.html#modified_env',
                                'fastcore.xtras.modify_exception': 'https://fastcore.fast.ai/xtras.html#modify_exception',
                                'fastcore.xtras.obj2dict': 'https://fastcore.fast.ai/xtras.html#obj2dict',
                                'fastcore.xtras.open_file': 'https://fastcore.fast.ai/xtras.html#open_file',
                                'fastcore.xtras.partial_format': 'https://fastcore.fast.ai/xtras.html#partial_format',
                                'fastcore.xtras.repo_details': 'https://fastcore.fast.ai/xtras.html#repo_details',
                                'fastcore.xtras.repr_dict': 'https://fastcore.fast.ai/xtras.html#repr_dict',
                                'fastcore.xtras.round_multiple': 'https://fastcore.fast.ai/xtras.html#round_multiple',
                                'fastcore.xtras.run': 'https://fastcore.fast.ai/xtras.html#run',
                                'fastcore.xtras.save_pickle': 'https://fastcore.fast.ai/xtras.html#save_pickle',
                                'fastcore.xtras.set_num_threads': 'https://fastcore.fast.ai/xtras.html#set_num_threads',
                                'fastcore.xtras.shufflish': 'https://fastcore.fast.ai/xtras.html#shufflish',
                                'fastcore.xtras.spark_chars': 'https://fastcore.fast.ai/xtras.html#spark_chars',
                                'fastcore.xtras.sparkline': 'https://fastcore.fast.ai/xtras.html#sparkline',
                                'fastcore.xtras.stringfmt_names': 'https://fastcore.fast.ai/xtras.html#stringfmt_names',
                                'fastcore.xtras.trace': 'https://fastcore.fast.ai/xtras.html#trace',
                                'fastcore.xtras.truncstr': 'https://fastcore.fast.ai/xtras.html#truncstr',
                                'fastcore.xtras.untar_dir': 'https://fastcore.fast.ai/xtras.html#untar_dir',
                                'fastcore.xtras.utc2local': 'https://fastcore.fast.ai/xtras.html#utc2local',
                                'fastcore.xtras.walk': 'https://fastcore.fast.ai/xtras.html#walk'}}}